@@ -816,16 +816,16 @@ def two_cluster_weighting(xpos, ypos, missing, downsamples, downsamp_filter, che
         
         # detect switches and weight of switch (= 1/number of switches in
         # portion)
-        switches = [[] for p in range(nd+1)]
-        switchesw = [[] for p in range(nd+1)]
+        switches  = [[] for p in range(nd+1)]
+        switchesw = np.empty(nd+1)
         for p in range(nd+1):
             switches[p] = np.abs(np.diff(IDL_d[p]))
-            switchesw[p]  = 1./np.sum(switches[p])
+            switchesw[p]= 1./np.sum(switches[p])
            
         # get nearest samples of switch and add weight
         weighted = np.hstack([switches[0]*switchesw[0],0])
         for p in range(nd):
-            j = np.array((np.argwhere(switches[p+1]).flatten()+1)*downsamples[p],dtype=int)-1
+            j = idxs[p][np.argwhere(switches[p+1]).flatten()]
             for o in range(int(downsamples[p])):
                 weighted[j+o] = weighted[j+o] + switchesw[p+1]
         
@@ -1530,4 +1530,4 @@ def I2MC(gazeData, options = None, logging=True, logging_offset=""):
   
     return fix,data,par
     
-    
\ No newline at end of file
+    
